<?php


namespace FiloBlu\ProductUrlTools\Helper;

use Magento\Framework\App\ObjectManager;
use Magento\Framework\DB\Helper\AbstractHelper;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\Unserialize\Unserialize;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    protected $resource;

    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Framework\App\ResourceConnection $resource,
        $modulePrefix = null
    )
    {
        $this->resource = $resource->getConnection();
        $this->scopeConfig = $context->getScopeConfig();

    }

    public function getAttributeOptionValueById($optionId)
    {
        //$res = $this->resource->getConnection();

        $productsQuery = $this->resource->select()
            ->from('eav_attribute_option_value')
            ->where('store_id = 0')
            ->where('option_id = ' . $optionId);
        return $this->resource->fetchAll($productsQuery);
    }

    /**
     * @param $optionId
     * @return int
     */
    public function countAttributeOptionValueById($optionId)
    {
        $productsQuery = $this->resource->select()
            ->from('eav_attribute_option_value')
            ->where('option_id = ' . $optionId);

        $res = $this->resource->fetchAll($productsQuery);
        return ($res) ? count($res) : 0;
    }

    /**
     * @param $optionValue
     * @param $notIn
     * @return array
     */
    public function getAttributeOptionValueByValue($optionValue, $notIn = '')
    {
        $productsQuery = $this->resource->select()
            ->from('eav_attribute_option_value')
            ->where('value = "' . $optionValue . '"')
            ->where('store_id = 0');

            if ($notIn) {
                $productsQuery->where('option_id NOT IN (' . $notIn . ')');
            }

        return $this->resource->fetchAll($productsQuery);
    }

    /**
     * @return array
     */
    public function getAttributeTypes()
    {
        //SELECT x.* FROM forteforte.eav_attribute x
        //WHERE attribute_code LIKE '%color%'
        $attributesQuery = $this->resource->select()
            ->from('eav_attribute')
            ->where('entity_type_id = 4')
            ->where('frontend_input = "select"');
        return $this->resource->fetchAll($attributesQuery);

    }

    /**
     * @param $optionId
     * @param $type
     * @return array
     */
    public function getProducts($optionId, $type = 'int')
    {
        $productsQuery = $this->resource->select()
            ->from('catalog_product_entity AS cpe', ['row_id', 'entity_id',  'sku'])
            ->joinInner('catalog_product_entity_'.$type.' AS cpei', 'cpe.row_id = cpei.row_id', ['attribute_id', 'value'])
            ->joinInner('eav_attribute_option_value AS eaov', 'cpei.value = eaov.option_id', ['value', 'option_id'])
            ->where('eaov.option_id = ' . $optionId)
            ->where('eaov.store_id = 0');
        return $this->resource->fetchAll($productsQuery);
    }

    /**
     * @param $item
     * @param $array
     * @param $column
     * @return false|int|string
     */
    public function arraySearch($item, $array, $column)
    {
        try{
            foreach ($array as $key => $value) {
                if(is_array($value)){
                    array_walk_recursive($value, function($v, $k) use($item ,$key,$value,&$val){
                        if(strpos($v, $item) !== false )  $val = $key;
                    });
                }else{
                    if(strpos($value, $item) !== false )  $val = $key;
                }

            }
            return $val;

        }catch (Exception $e) {
            return false;
        }
    }

    /**
     * @param $a
     * @param $b
     * @return int
     */
    public function sortCount($a, $b)
    {
        if($a['products']==$b['products']) return 0;
        return $a['products'] < $b['products']?1:-1;
    }

    /**
     * @return array
     */
    public function getAttributeConfig(){
        $attributes = $this->getSerializedValue($this->scopeConfig->getValue('producturltools/general/attribute'));
        $attributes = array_values($attributes);

        foreach($attributes as $key =>$value){
            $valuex = $value['column_name'];
           // array_push($attribute,  $value['column_name']);
            $attributex [] = $valuex;

        }

        return $attributex;
    }

    /**
     * @param string $value
     * @return mixed
     */
    public function getSerializedValue($value)
    {
        if ($this->isSerialized($value)) {
            $unserializer = ObjectManager::getInstance()->get(Unserialize::class);
        } else {
            $unserializer = ObjectManager::getInstance()->get(Json::class);
        }

        return $unserializer->unserialize($value);
    }
    public function isSerialized($value)
    {
        return (boolean)preg_match('/^((s|i|d|b|a|O|C):|N;)/', $value);
    }
}
